# [Replcraft](https://mc.repl.game/replcraft/) client library for Python using websocket-client

Docs:
+ https://rex-bot.ga/replcraft-python/src/replcraft/main.html
+ https://mc.repl.game/replcraft/
+ https://blog.replit.com/automating-minecraft-on-replit

Template: https://git.rexum.space/rexum/replcraft-examples

Blog post: https://blog.replit.com/automating-minecraft-on-replit

Server: https://mc.repl.game

